package com.sf.order.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.sf.common.annotation.Excel;
import com.sf.common.core.domain.BaseEntity;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.util.Date;

/**
 * 订单基础信息对象 ORDER_INFO
 *
 * @author ztzh
 * @date 2024-04-09
 */
public class OrderInfo extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 订单编号
     */
    @Excel(name = "订单编号")
    private Long orderNo;

    /**
     * 订单状态:
     * 0:待支付
     * 1:已付款
     * 2:支付超时系统结束
     * 3:已完成
     */
    @Excel(name = "订单状态: 0:待支付 1:已付款 2:支付超时系统结束 3:已完成 ")
    private Long orderStatus;

    /**
     * 支付方式:0-点券 1-现金
     */
    @Excel(name = "支付方式:0-点券 1-现金")
    private Long payType;

    /**
     * 支付渠道(支付方式为现金时)
     * 0:微信
     * 1:支付宝
     */
    @Excel(name = "支付渠道(支付方式为现金时) 0:微信 1:支付宝")
    private Long payChannel;

    /**
     * 订单金额
     */
    @Excel(name = "订单金额")
    private Long orderAmt;

    /**
     * 运费
     */
    @Excel(name = "运费")
    private Long freightAmt;

    /**
     * 总金额
     */
    @Excel(name = "总金额")
    private Long payAmt;

    /**
     * 实际支付金额
     */
    @Excel(name = "实际支付金额")
    private Long reallyAmt;

    /**
     * 收件方式
     * ：0-自提
     * 1-快递 2-配送
     */
    @Excel(name = "收件方式：0-自提 1-快递 2-配送")
    private Long receiveType;

    /**
     * 商品Id
     */
    @Excel(name = "商品Id")
    private Long goodsId;

    /**
     * 商户Id
     */
    @Excel(name = "商户Id")
    private Long businessId;

    /**
     * 收货地址配置Id
     */
    @Excel(name = "收货地址配置Id")
    private Long receiveAddrId;

    /**
     * 支付时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "支付时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date payTime;

    /**
     * 订单创建人
     */
    @Excel(name = "订单创建人")
    private Long createUserId;

    /**
     * 最后一次更新操作人
     */
    @Excel(name = "最后一次更新操作人")
    private Long updateUserId;

    /**
     * 逻辑删除标识
     * 0:未删除
     * 1:已删除
     */
    @Excel(name = "逻辑删除标识 0:未删除 1:已删除")
    private Long isDelete;

    /**
     * 快递单号
     */
    @Excel(name = "快递单号")
    private String trackNo;

    /**
     * 订单类型0:自动1:手动
     */
    @Excel(name = "订单类型0:自动1:手动")
    private Long orderType;

    /**
     * 平台外部订单号
     */
    @Excel(name = "平台外部订单号")
    private Long outOrderNo;

    /**
     * 平台支付返回值
     */
    @Excel(name = "平台支付返回值")
    private String payData;

    /**
     * 减免金额(优惠券抵扣)
     */
    @Excel(name = "减免金额(优惠券抵扣)")
    private Long reductionAmout;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setOrderNo(Long orderNo) {
        this.orderNo = orderNo;
    }

    public Long getOrderNo() {
        return orderNo;
    }

    public void setOrderStatus(Long orderStatus) {
        this.orderStatus = orderStatus;
    }

    public Long getOrderStatus() {
        return orderStatus;
    }

    public void setPayType(Long payType) {
        this.payType = payType;
    }

    public Long getPayType() {
        return payType;
    }

    public void setPayChannel(Long payChannel) {
        this.payChannel = payChannel;
    }

    public Long getPayChannel() {
        return payChannel;
    }

    public void setOrderAmt(Long orderAmt) {
        this.orderAmt = orderAmt;
    }

    public Long getOrderAmt() {
        return orderAmt;
    }

    public void setFreightAmt(Long freightAmt) {
        this.freightAmt = freightAmt;
    }

    public Long getFreightAmt() {
        return freightAmt;
    }

    public void setPayAmt(Long payAmt) {
        this.payAmt = payAmt;
    }

    public Long getPayAmt() {
        return payAmt;
    }

    public void setReallyAmt(Long reallyAmt) {
        this.reallyAmt = reallyAmt;
    }

    public Long getReallyAmt() {
        return reallyAmt;
    }

    public void setReceiveType(Long receiveType) {
        this.receiveType = receiveType;
    }

    public Long getReceiveType() {
        return receiveType;
    }

    public void setGoodsId(Long goodsId) {
        this.goodsId = goodsId;
    }

    public Long getGoodsId() {
        return goodsId;
    }

    public void setBusinessId(Long businessId) {
        this.businessId = businessId;
    }

    public Long getBusinessId() {
        return businessId;
    }

    public void setReceiveAddrId(Long receiveAddrId) {
        this.receiveAddrId = receiveAddrId;
    }

    public Long getReceiveAddrId() {
        return receiveAddrId;
    }

    public void setPayTime(Date payTime) {
        this.payTime = payTime;
    }

    public Date getPayTime() {
        return payTime;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setUpdateUserId(Long updateUserId) {
        this.updateUserId = updateUserId;
    }

    public Long getUpdateUserId() {
        return updateUserId;
    }

    public void setIsDelete(Long isDelete) {
        this.isDelete = isDelete;
    }

    public Long getIsDelete() {
        return isDelete;
    }

    public void setTrackNo(String trackNo) {
        this.trackNo = trackNo;
    }

    public String getTrackNo() {
        return trackNo;
    }

    public void setOrderType(Long orderType) {
        this.orderType = orderType;
    }

    public Long getOrderType() {
        return orderType;
    }

    public void setOutOrderNo(Long outOrderNo) {
        this.outOrderNo = outOrderNo;
    }

    public Long getOutOrderNo() {
        return outOrderNo;
    }

    public void setPayData(String payData) {
        this.payData = payData;
    }

    public String getPayData() {
        return payData;
    }

    public void setReductionAmout(Long reductionAmout) {
        this.reductionAmout = reductionAmout;
    }

    public Long getReductionAmout() {
        return reductionAmout;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("id", getId())
                .append("orderNo", getOrderNo())
                .append("orderStatus", getOrderStatus())
                .append("payType", getPayType())
                .append("payChannel", getPayChannel())
                .append("orderAmt", getOrderAmt())
                .append("freightAmt", getFreightAmt())
                .append("payAmt", getPayAmt())
                .append("reallyAmt", getReallyAmt())
                .append("receiveType", getReceiveType())
                .append("goodsId", getGoodsId())
                .append("businessId", getBusinessId())
                .append("receiveAddrId", getReceiveAddrId())
                .append("createTime", getCreateTime())
                .append("payTime", getPayTime())
                .append("createUserId", getCreateUserId())
                .append("updateUserId", getUpdateUserId())
                .append("isDelete", getIsDelete())
                .append("updateTime", getUpdateTime())
                .append("trackNo", getTrackNo())
                .append("orderType", getOrderType())
                .append("outOrderNo", getOutOrderNo())
                .append("payData", getPayData())
                .append("reductionAmout", getReductionAmout())
                .toString();
    }
}
